@@ -18,6 +18,7 @@ type_map = {
     "int": int,
     "float": float,
     "complex": complex,
+    "bool": bool,
     "datetime": datetime.datetime,
     "date": datetime.date,
     "timedelta": datetime.timedelta,
@@ -106,7 +107,7 @@ class ADFMetaColumn(ToDictMixin):
 
     def handle_matching(self, ads: AbstractDataStructure) -> AbstractDataStructure:
         logging.info(
-            f"Handling matched column '{self.name}' with cast '{self.cast.__name__}'..."
+            f"Handling matched column '{self.name}' with cast '{self.cast.__name__ if self.cast is not None else 'NONE'}'..."
         )
         if self.cast is not None:
             ads[self.name] = ads[self.name].as_type(self.cast)
