@@ -5,4 +5,6 @@ from .aws_transitions import (
     LambdaToEMRTransition,
     EMRToEMRTransition,
     EMRToRedshiftTransition,
+    EMRToAthenaTransition,
+    AthenaToAthenaTransition,
 )
